@@ -192,7 +192,8 @@ sub value_quote {
 }
 
 sub navigation_header {
-    if (defined $::COOKIE{"BUGLIST"} && $::COOKIE{"BUGLIST"} ne "") {
+    if (defined $::COOKIE{"BUGLIST"} && $::COOKIE{"BUGLIST"} ne "" &&
+        defined $::FORM{'id'}) {
 	my @bugs = split(/:/, $::COOKIE{"BUGLIST"});
 	my $cur = lsearch(\@bugs, $::FORM{"id"});
 	print "<B>Bug List:</B> (@{[$cur + 1]} of @{[$#bugs + 1]})\n";
@@ -220,6 +221,7 @@ sub make_options {
     my $last = "";
     my $popup = "";
     my $found = 0;
+    $default = "" if !defined $default;
 
     if ($src) {
         foreach my $item (@$src) {
@@ -281,7 +283,11 @@ sub quietly_check_login() {
     if (defined $::COOKIE{"Bugzilla_login"} &&
 	defined $::COOKIE{"Bugzilla_logincookie"}) {
         ConnectToDatabase();
-        SendSQL("select profiles.groupset, profiles.login_name = " .
+        if (!defined $ENV{'REMOTE_HOST'}) {
+            $ENV{'REMOTE_HOST'} = $ENV{'REMOTE_ADDR'};
+        }
+        SendSQL("select profiles.groupset, profiles.login_name, " .
+                "profiles.login_name = " .
 		SqlQuote($::COOKIE{"Bugzilla_login"}) .
 		" and profiles.cryptpassword = logincookies.cryptpassword " .
 		"and logincookies.hostname = " .
@@ -291,9 +297,11 @@ sub quietly_check_login() {
 		" and profiles.userid = logincookies.userid");
         my @row;
         if (@row = FetchSQLData()) {
-            $loginok = $row[1];
+            $loginok = $row[2];
             if ($loginok) {
                 $::usergroupset = $row[0];
+                $::COOKIE{"Bugzilla_login"} = $row[1]; # Makes sure case is in
+                                                       # canonical form.
             }
         }
     }
@@ -308,16 +316,15 @@ sub quietly_check_login() {
 
 sub CheckEmailSyntax {
     my ($addr) = (@_);
-    if ($addr !~ /^[^@, ]*@[^@, ]*\.[^@, ]*$/) {
+    my $match = Param('emailregexp');
+    if ($addr !~ /$match/) {
         print "Content-type: text/html\n\n";
 
         print "<H1>Invalid e-mail address entered.</H1>\n";
         print "The e-mail address you entered\n";
         print "(<b>$addr</b>) didn't match our minimal\n";
-        print "syntax checking for a legal email address.  A legal\n";
-        print "address must contain exactly one '\@', and at least one\n";
-        print "'.' after the \@, and may not contain any commas or.\n";
-        print "spaces.\n";
+        print "syntax checking for a legal email address.\n";
+        print Param('emailregexpdesc');
         print "<p>Please click <b>back</b> and try again.\n";
         exit;
     }
@@ -325,6 +332,40 @@ sub CheckEmailSyntax {
 
 
 
+sub MailPassword {
+    my ($login, $password) = (@_);
+    my $urlbase = Param("urlbase");
+    my $template = "From: bugzilla-daemon
+To: %s
+Subject: Your bugzilla password.
+
+To use the wonders of bugzilla, you can use the following:
+
+ E-mail address: %s
+       Password: %s
+
+ To change your password, go to:
+ ${urlbase}changepassword.cgi
+
+ (Your bugzilla and CVS password, if any, are not currently synchronized.
+ Top hackers are working around the clock to fix this, as you read this.)
+";
+    my $msg = sprintf($template, $login . Param('emailsuffix'),
+                      $login, $password);
+
+    open SENDMAIL, "|/usr/lib/sendmail -t";
+    print SENDMAIL $msg;
+    close SENDMAIL;
+
+    print "Content-type: text/html\n\n";
+    print "<H1>Password has been emailed.</H1>\n";
+    print "The password for the e-mail address\n";
+    print "$login has been e-mailed to that address.\n";
+    print "<p>When the e-mail arrives, you can click <b>Back</b>\n";
+    print "and enter your password in the form there.\n";
+}
+
+
 sub confirm_login {
     my ($nexturl) = (@_);
 
@@ -344,41 +385,13 @@ sub confirm_login {
         if (defined $::FORM{"PleaseMailAPassword"}) {
 	    my $realpwd;
             if ($realcryptpwd eq "") {
-		$realpwd = InsertNewUser($enteredlogin);
+		$realpwd = InsertNewUser($enteredlogin, "");
             } else {
                 SendSQL("select password from profiles where login_name = " .
 			SqlQuote($enteredlogin));
 		$realpwd = FetchOneColumn();
             }
-            my $urlbase = Param("urlbase");
-            my $template = "From: bugzilla-daemon
-To: %s
-Subject: Your bugzilla password.
-
-To use the wonders of bugzilla, you can use the following:
-
- E-mail address: %s
-       Password: %s
-
- To change your password, go to:
- ${urlbase}changepassword.cgi
-
- (Your bugzilla and CVS password, if any, are not currently synchronized.
- Top hackers are working around the clock to fix this, as you read this.)
-";
-            my $msg = sprintf($template, $enteredlogin, $enteredlogin,
-			      $realpwd);
-            
-	    open SENDMAIL, "|/usr/lib/sendmail -t";
-	    print SENDMAIL $msg;
-	    close SENDMAIL;
-
-            print "Content-type: text/html\n\n";
-            print "<H1>Password has been emailed.</H1>\n";
-            print "The password for the e-mail address\n";
-            print "$enteredlogin has been e-mailed to that address.\n";
-            print "<p>When the e-mail arrives, you can click <b>Back</b>\n";
-            print "and enter your password in the form there.\n";
+            MailPassword($enteredlogin, $realpwd);
             exit;
         }
 
@@ -391,6 +404,9 @@ To use the wonders of bugzilla, you can use the following:
             exit;
         }
         $::COOKIE{"Bugzilla_login"} = $enteredlogin;
+        if (!defined $ENV{'REMOTE_HOST'}) {
+            $ENV{'REMOTE_HOST'} = $ENV{'REMOTE_ADDR'};
+        }
 	SendSQL("insert into logincookies (userid,cryptpassword,hostname) values (@{[DBNameToIdAndCheck($enteredlogin)]}, @{[SqlQuote($realcryptpwd)]}, @{[SqlQuote($ENV{'REMOTE_HOST'})]})");
         SendSQL("select LAST_INSERT_ID()");
         my $logincookie = FetchOneColumn();
@@ -420,7 +436,7 @@ To use the wonders of bugzilla, you can use the following:
 	    $nexturl = $&;
         }
         my $method = "POST";
-        if (defined $ENV{"REQUEST_METHOD"}) {
+        if (defined $ENV{"REQUEST_METHOD"} && length($::buffer) > 1) {
             $method = $ENV{"REQUEST_METHOD"};
         }
         print "
@@ -465,7 +481,7 @@ name=PleaseMailAPassword>
 
 
 sub PutHeader {
-    my ($title, $h1, $h2) = (@_);
+    my ($title, $h1, $h2, $extra) = (@_);
 
     if (!defined $h1) {
 	$h1 = $title;
@@ -473,11 +489,14 @@ sub PutHeader {
     if (!defined $h2) {
 	$h2 = "";
     }
+    if (!defined $extra) {
+	$extra = "";
+    }
 
     print "<HTML><HEAD>\n<TITLE>$title</TITLE>\n";
     print Param("headerhtml") . "\n</HEAD>\n";
     print "<BODY   BGCOLOR=\"#FFFFFF\" TEXT=\"#000000\"\n";
-    print "LINK=\"#0000EE\" VLINK=\"#551A8B\" ALINK=\"#FF0000\">\n";
+    print "LINK=\"#0000EE\" VLINK=\"#551A8B\" ALINK=\"#FF0000\" $extra>\n";
 
     print PerformSubsts(Param("bannerhtml"), undef);
 
@@ -500,6 +519,52 @@ sub PutHeader {
 }
 
 
+sub DumpBugActivity {
+    my ($id, $starttime) = (@_);
+    my $datepart = "";
+    if (defined $starttime) {
+        $datepart = "and bugs_activity.when >= $starttime";
+    }
+    my $query = "
+        select bugs_activity.field, bugs_activity.when,
+                bugs_activity.oldvalue, bugs_activity.newvalue,
+                profiles.login_name
+        from bugs_activity,profiles
+        where bugs_activity.bug_id = $id $datepart
+        and profiles.userid = bugs_activity.who
+        order by bugs_activity.when";
+
+    SendSQL($query);
+    
+    print "<table border cellpadding=4>\n";
+    print "<tr>\n";
+    print "    <th>Who</th><th>What</th><th>Old value</th><th>New value</th><th>When</th>\n";
+    print "</tr>\n";
+    
+    my @row;
+    while (@row = FetchSQLData()) {
+        my ($field,$when,$old,$new,$who) = (@row);
+        $old = value_quote($old);
+        $new = value_quote($new);
+        if ($old eq "") {
+            $old = "&nbsp;";
+        }
+        if ($new eq "") {
+            $new = "&nbsp;";
+        }
+        print "<tr>\n";
+        print "<td>$who</td>\n";
+        print "<td>$field</td>\n";
+        print "<td>$old</td>\n";
+        print "<td>$new</td>\n";
+        print "<td>$when</td>\n";
+        print "</tr>\n";
+    }
+    print "</table>\n";
+}
+
+
+
 
 
 
