@@ -17,6 +17,7 @@
 # Netscape Communications Corporation. All Rights Reserved.
 # 
 # Contributor(s): Terry Weissman <terry@mozilla.org>
+#                 Dawn Endico <endico@mozilla.org>
 
 
 # This file defines all the parameters that we have a GUI to edit within
@@ -154,8 +155,8 @@ DefParam("blurbhtml",
          "l",
          "This is <B>Bugzilla</B>: the Mozilla bug system.  For more 
 information about what Bugzilla is and what it can do, see 
-<A HREF=http://www.mozilla.org/>mozilla.org</A>'s
-<A HREF=http://www.mozilla.org/bugs/><B>bug pages</B></A>.");
+<A HREF=\"http://www.mozilla.org/\">mozilla.org</A>'s
+<A HREF=\"http://www.mozilla.org/bugs/\"><B>bug pages</B></A>.");
 
 
 
@@ -238,7 +239,7 @@ You will get this message once a day until you've dealt with these bugs!
 DefParam("defaultquery",
  	 "This is the default query that initially comes up when you submit a bug.  It's in URL parameter format, which makes it hard to read.  Sorry!",
 	 "t",
-	 "bug_status=NEW&bug_status=ASSIGNED&bug_status=REOPENED&product=Mozilla&order=%22Importance%22");
+	 "bug_status=NEW&bug_status=ASSIGNED&bug_status=REOPENED&order=%22Importance%22");
 
 
 DefParam("letsubmitterchoosepriority",
@@ -276,6 +277,12 @@ DefParam("nummilestones",
          10,
          \&check_numeric);
 
+DefParam("curmilestone",
+         "If using Target Milestone, Which milestone are we working toward right now?",
+         "t",
+         1,
+         \&check_numeric);
+
 DefParam("useqacontact",
 	 "Do you wish to use the QA Contact field?",
 	 "b",
@@ -286,7 +293,46 @@ DefParam("usestatuswhiteboard",
 	 "b",
 	 0);
 
-	 
+DefParam("usebrowserinfo",
+	 "Do you want bug reports to be assigned an OS & Platform based on the browser
+	  the user makes the report from?",
+	 "b",
+	 1);
+
+DefParam("usedependencies",
+         "Do you wish to use dependencies (allowing you to mark which bugs depend on which other ones)?",
+         "b",
+         1);
+
+DefParam("webdotbase",
+         "This is the URL prefix that is common to all requests for webdot.  The <a href=\"http://www.research.att.com/~north/cgi-bin/webdot.cgi\">webdot package</a> is a very swell thing that generates pictures of graphs.  If you have an installation of bugsplat that hides behind a firewall, then to get graphs to work, you will have to install a copy of webdot behind your firewall, and change this path to match.  Also, webdot has some trouble with software domain names, so you may have to play games and hack the %urlbase% part of this.  If this all seems like too much trouble, you can set this paramater to be the empty string, which will cause the graphing feature to be disabled entirely.",
+         "t",
+         "http://www.research.att.com/~north/cgi-bin/webdot.cgi/%urlbase%");
+
+DefParam("entryheaderhtml",
+         "This is a special header for the bug entry page. The text will be printed after the page header, before the bug entry form. It is meant to be a place to put pointers to intructions on how to enter bugs.",
+         "l",
+         '');
+
+DefParam("expectbigqueries",
+         "If this is on, then we will tell mysql to <tt>set option SQL_BIG_TABLES=1</tt> before doing queries on bugs.  This will be a little slower, but one will not get the error <tt>The table ### is full</tt> for big queries that require a big temporary table.",
+         "b",
+         0);
+
+DefParam("emailregexp",
+         'This defines the regexp to use for legal email addresses.  The default tries to match fully qualified email addresses.  Another popular value to put here is <tt>^[^@, ]$</tt>, which means "local usernames, no @ allowed.',
+         "t",
+         q:^[^@, ]*@[^@, ]*\\.[^@, ]*$:);
+
+DefParam("emailregexpdesc",
+         "This describes in english words what kinds of legal addresses are allowed by the <tt>emailregexp</tt> param.",
+         "l",
+         "A legal address must contain exactly one '\@', and at least one '.' after the \@, and may not contain any commas or spaces.");
+
+DefParam("emailsuffix",
+         "This is a string to append to any email addresses when actually sending mail to that address.  It is useful if you have changed the <tt>emailregexp</tt> param to only allow local usernames, but you want the mail to be delivered to username\@my.local.hostname.",
+         "t",
+         "");
 
 
 1;
